##  Overview
The AI agent hub dashboard offers an overview of resources for AI agent data in your workspace. On the dashboard, you can monitor key performance indicators (KPIs) for AI agents, view the status of discovered AI agents, preview dedicated reports, and navigate to related items.
You can find the AI agent hub dashboard in predefined dashboards. Access it from the Predefined section or the All Dashboards section on the dashboards page.
![](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loioe29c7146bc0344769a92d57f5f94a74c_LowRes.png)
AI Agent Hub Dashboard
